/* Ping))) Sensor / Ultrahangos távolságérzékelő szenzor (Parallax)
 
 Áramkör
 * +V PING))) bekötve Arduino +5 V-ba
 * GND PING))) bekötve Arduino GND-be
 * SIG PING))) bekötve Arduino digitális 7 pinbe
 
 created 3 Nov 2008 by David A. Mellis
 modified 30 Aug 2011 by Tom Igoe
 */

// állandóval meghatározzuk a szenzor pint:
const int pingPin = 7;

void setup() {
  // inicializáljuk a soros kommunikációt:
  Serial.begin(9600);
}


void loop() {
  // long változóban tároljuk a ping idejét
  // a távolság eredményét pedig inch-ben és cm-ben
  long duration, inches, cm;

  // Előidézzük a PING)))-et egy minimum 
  // 2 mikroszekundumos HIGH impulzussal.
  // Egy rövid LOW impulzus előzi meg 
  // a HIGH impulzust, hogy tisztán kapjuk meg:
  pinMode(pingPin, OUTPUT);
  digitalWrite(pingPin, LOW);
  delayMicroseconds(2);
  digitalWrite(pingPin, HIGH);
  delayMicroseconds(5);
  digitalWrite(pingPin, LOW);

  // Ugyanazt a pint használjuk a visszajövő 
  // impulzus kiolvasásához, ahol a HIGH impulzus
  // időtartama a kiküldéstől a visszaérkezésig tart:
  pinMode(pingPin, INPUT);
  duration = pulseIn(pingPin, HIGH);

  // az időtartamot távolsággá alakítjuk:
  inches = microsecondsToInches(duration);
  cm = microsecondsToCentimeters(duration);

  Serial.print(inches);
  Serial.print("in, ");
  Serial.print(cm);
  Serial.print("cm");
  Serial.println();

  delay(100);
}


long microsecondsToInches(long microseconds) {
  /* Parallax's használati utasítása szerint, 73.746 mikroszekundum egy inchnek felel meg. Mivel az impulzus oda-vissza megy, a kapott adatot elosztjuk 2-vel. Lásd: http://www.parallax.com/dl/docs/prod/acc/28015-PING-v1.3.pdf */

  return microseconds / 74 / 2;
}


long microsecondsToCentimeters(long microseconds) {
  /* A hangunk sebessége 340 m/s vagy 29 centiméterenként. Mivel oda-vissza mértük az impulzust, a valós távolsághoz el kell osztanunk 2-vel: */
  return microseconds / 29 / 2;
}


